@@ -14,7 +14,7 @@
 #define MAIN                        // Define external variables
 #include "rmagick.h"
 
-#if defined(HAVE_SETMAGICKALIGNEDMEMORYMETHODS) && defined(HAVE_RB_GC_ADJUST_MEMORY_USAGE)
+#if defined(HAVE_SETMAGICKALIGNEDMEMORYMETHODS)
     #if defined(HAVE_POSIX_MEMALIGN) || defined(HAVE__ALIGNED_MSIZE)
         #define USE_RM_ALIGNED_MALLOC 1
 
@@ -1019,10 +1019,8 @@ Init_RMagick2(void)
         ENUMERATOR(ShapeAlphaChannel)
         ENUMERATOR(TransparentAlphaChannel)
         ENUMERATOR(BackgroundAlphaChannel)
-#if defined(IMAGEMAGICK_GREATER_THAN_EQUAL_6_8_9)
         ENUMERATOR(AssociateAlphaChannel)
         ENUMERATOR(DisassociateAlphaChannel)
-#endif
 #if defined(IMAGEMAGICK_7)
         ENUMERATOR(OnAlphaChannel)
         ENUMERATOR(OffAlphaChannel)
@@ -1052,7 +1050,12 @@ Init_RMagick2(void)
         ENUMERATOR(BlackChannel)
         ENUMERATOR(IndexChannel)
         ENUMERATOR(GrayChannel)
+        ENUMERATOR(CompositeChannels)
         ENUMERATOR(AllChannels)
+        ENUMERATOR(TrueAlphaChannel)
+        ENUMERATOR(RGBChannels)
+        ENUMERATOR(GrayChannels)
+        ENUMERATOR(SyncChannels)
         ENUMERATORV(AlphaChannel, OpacityChannel)
         ENUMERATORV(DefaultChannels, 0xff & ~OpacityChannel)
         ENUMERATORV(HueChannel, RedChannel)
@@ -1090,7 +1093,6 @@ Init_RMagick2(void)
         ENUMERATOR(Rec709YCbCrColorspace)
         ENUMERATOR(LogColorspace)
         ENUMERATOR(CMYColorspace)
-#if defined(IMAGEMAGICK_GREATER_THAN_EQUAL_6_8_9)
         ENUMERATOR(LuvColorspace)
         ENUMERATOR(HCLColorspace)
         ENUMERATOR(LCHColorspace)
@@ -1103,7 +1105,6 @@ Init_RMagick2(void)
         ENUMERATOR(HCLpColorspace)
         ENUMERATOR(YDbDrColorspace)
         ENUMERATORV(XyYColorspace, xyYColorspace)
-#endif
 #if defined(IMAGEMAGICK_7)
 #if defined(IMAGEMAGICK_GREATER_THAN_EQUAL_7_0_8)
         ENUMERATOR(LinearGRAYColorspace)
@@ -1196,9 +1197,7 @@ Init_RMagick2(void)
         ENUMERATOR(UndefinedCompositeOp)
         ENUMERATOR(VividLightCompositeOp)
         ENUMERATOR(XorCompositeOp)
-#if defined(IMAGEMAGICK_GREATER_THAN_EQUAL_6_8_9)
         ENUMERATOR(HardMixCompositeOp)
-#endif
 #if defined(IMAGEMAGICK_7)
         ENUMERATOR(CopyAlphaCompositeOp)
 #else
@@ -1242,6 +1241,7 @@ Init_RMagick2(void)
 
     // DisposeType constants
     DEF_ENUM(DisposeType)
+        ENUMERATOR(UnrecognizedDispose)
         ENUMERATOR(UndefinedDispose)
         ENUMERATOR(BackgroundDispose)
         ENUMERATOR(NoneDispose)
@@ -1318,9 +1318,7 @@ Init_RMagick2(void)
         ENUMERATOR(RobidouxSharpFilter)
         ENUMERATOR(CosineFilter)
         ENUMERATOR(SplineFilter)
-#if defined(IMAGEMAGICK_GREATER_THAN_EQUAL_6_8_9)
         ENUMERATOR(LanczosRadiusFilter)
-#endif
         ENUMERATORV(WelchFilter, WelshFilter)
         ENUMERATORV(HannFilter, HanningFilter)
     END_ENUM
@@ -1412,9 +1410,7 @@ Init_RMagick2(void)
         ENUMERATOR(RootMeanSquaredErrorMetric)
         ENUMERATOR(NormalizedCrossCorrelationErrorMetric)
         ENUMERATOR(FuzzErrorMetric)
-#if defined(IMAGEMAGICK_GREATER_THAN_EQUAL_6_8_9)
         ENUMERATOR(PerceptualHashErrorMetric)
-#endif
 #if defined(IMAGEMAGICK_7)
         ENUMERATOR(UndefinedErrorMetric)
         ENUMERATOR(MeanErrorPerPixelErrorMetric)
@@ -1546,9 +1542,7 @@ Init_RMagick2(void)
         ENUMERATOR(ExponentialQuantumOperator)
         ENUMERATOR(MedianQuantumOperator)
         ENUMERATOR(SumQuantumOperator)
-#if defined(IMAGEMAGICK_GREATER_THAN_EQUAL_6_8_9)
         ENUMERATOR(RootMeanSquareQuantumOperator)
-#endif
     END_ENUM
 
     // RenderingIntent
@@ -1673,9 +1667,7 @@ Init_RMagick2(void)
         ENUMERATOR(CorrelateNormalizeValue)
         ENUMERATOR(AreaValue)
         ENUMERATOR(DecimalValue)
-#if defined(IMAGEMAGICK_GREATER_THAN_EQUAL_6_8_9)
         ENUMERATOR(SeparatorValue)
-#endif
         ENUMERATOR(AllValues)
     END_ENUM
 
@@ -1744,9 +1736,7 @@ Init_RMagick2(void)
       ENUMERATOR(OctagonalKernel)
       ENUMERATOR(EuclideanKernel)
       ENUMERATOR(UserDefinedKernel)
-#if defined(IMAGEMAGICK_GREATER_THAN_EQUAL_6_8_9)
       ENUMERATOR(BinomialKernel)
-#endif
     END_ENUM
 
     /*-----------------------------------------------------------------------*/
@@ -1822,25 +1812,20 @@ Init_RMagick2(void)
  * were compiled with.
  *
  * No Ruby usage (internal function)
- *
- * Notes:
- *   - Bypass the test by defining the constant RMAGICK_BYPASS_VERSION_TEST to
- *     'true' at the top level, before requiring 'rmagick'
  */
 static void
 test_Magick_version(void)
 {
     size_t version_number;
     const char *version_str;
-    ID bypass = rb_intern("RMAGICK_BYPASS_VERSION_TEST");
 
-    if (RTEST(rb_const_defined(rb_cObject, bypass)) && RTEST(rb_const_get(rb_cObject, bypass)))
-    {
-        return;
-    }
+    /* ImageMagick versions are defined as major, minor and patch, each of which are defined as a value in 1 byte. */
+    /* ImageMagick 6.9.12 has `#define MagickLibVersion  0x69C` */
+    /* It use only major and minor versions. */
+    size_t mask_major_minor_version = 0xFFFFFFF0;
 
     version_str = GetMagickVersion(&version_number);
-    if (version_number != MagickLibVersion)
+    if ((version_number & mask_major_minor_version) != (MagickLibVersion & mask_major_minor_version))
     {
         int n, x;
 
